==> visual-third-party-1.1.0-richnco-sources.jar: com/tenqube/visual_third/manager/VisualAlarmManager.java <==
package com.tenqube.visual_third.manager;

import android.app.AlarmManager;
import android.app.PendingIntent;
import android.content.Context;
import android.content.Intent;
import android.os.Bundle;

import com.tenqube.visual_third.entity.VisualNotification;
import com.tenqube.visual_third.repository.VisualRepository;
import com.tenqube.visual_third.service.AlarmService;
import com.tenqube.visual_third.util.Utils;

import java.util.ArrayList;
import java.util.Calendar;

import static tenqube.parser.core.ParserService.mIsDebug;
import static tenqube.parser.util.LogUtil.LOGI;

public class VisualAlarmManager {

    public static final String TAG = VisualAlarmManager.class.getSimpleName();
    private static final int ALARM_SET = 0;
    private static final int ALARM_REPEAT = 1;


    private Context context;
    private static VisualAlarmManager mInstance = null;
    private AlarmManager alarmManager;
    private VisualRepository repository;

    public static VisualAlarmManager getInstance(Context ctx) {
        synchronized (VisualAlarmManager.class) {
            if (mInstance == null) {
                mInstance = new VisualAlarmManager(ctx.getApplicationContext());
            }
        }
        return mInstance;
    }

    private VisualAlarmManager(Context context) {
        this.context = context;
        alarmManager = (AlarmManager) context.getSystemService(Context.ALARM_SERVICE);
        repository = VisualRepository.getInstance(context);
    }

    /**
     * 호출 시점
     * 1. 처음 진입시
     * 2. 설정 변경시
     */
    public void setAlarms() {

        ArrayList<VisualNotification> notifications = repository.loadNotifications();
        for(VisualNotification notification : notifications) {
            cancelAlarm(notification);
            if(notification.isEnable()) {
                setAlarm(notification);
            }
        }
    }

    private void setAlarm(VisualNotification notification) {
        PendingIntent pIntent = createPendingIntent(notification);
        long alarmTime = calculateAlarmTime(notification);
        long currentTime = System.currentTimeMillis();

        alarmManager.set(AlarmManager.RTC_WAKEUP, currentTime + 5000, pIntent);
    }

    private void cancelAlarm(VisualNotification notification) {
        PendingIntent pIntent = createPendingIntent(notification);
        alarmManager.cancel(pIntent);
    }

    private PendingIntent createPendingIntent(VisualNotification notification) {
        Intent intent = new Intent(context, AlarmService.class);

        Bundle bundle = new Bundle();
        bundle.putSerializable("data", notification);
        intent.putExtra("bundle", bundle);
        return PendingIntent.getService(context, notification.getId(), intent, PendingIntent.FLAG_UPDATE_CURRENT);
    }

    private long calculateAlarmTime(VisualNotification notification) {

        Calendar calendar = Calendar.getInstance();
        long currentTime = calendar.getTimeInMillis();
        int currentDay = calendar.get(Calendar.DATE);

        int currentHour = calendar.get(Calendar.HOUR_OF_DAY);

        calendar.set(Calendar.MINUTE, 0);
        calendar.set(Calendar.SECOND, 0);

        int day = notification.getDay();
        int dayOfWeek = notification.getDayOfWeek();
        int hour = notification.getHour();

        switch (notification.getName()) {
            case "monthly":
                if(day == currentDay) { // 1일로같음
                    if(currentHour >= hour) { // 알람설정 시간을 지나침
                        calendar.add(Calendar.MONTH, 1);
                    }
                } else {
                    calendar.add(Calendar.MONTH, 1);
                }

                calendar.set(Calendar.DATE, day);
                calendar.set(Calendar.HOUR_OF_DAY, hour);
                break;

            case "weekly_mon":
            case "weekly_fri":
                calendar.set(Calendar.HOUR_OF_DAY, hour);
                calendar.set(Calendar.DAY_OF_WEEK, dayOfWeek);

                if(currentTime >= calendar.getTimeInMillis()) {
                    calendar.add(Calendar.WEEK_OF_YEAR, 1);
                }
                break;

            case "daily":
                calendar.set(Calendar.HOUR_OF_DAY, hour);

                if(currentTime >= calendar.getTimeInMillis()) {
                    calendar.add(Calendar.DATE, 1);
                }
                break;
        }

        LOGI(TAG, "notification.getName()" + notification.getName(), mIsDebug);
        LOGI(TAG, "Alarm Date: " + Utils.getStringDateAsYYYYMMddHHmmss(calendar), mIsDebug);
        return calendar.getTimeInMillis();


    }

}

==> visual-third-party-1.2.2-richnco-sources.jar: com/tenqube/visual_third/manager/VisualAlarmManager.java <==
package com.tenqube.visual_third.manager;

import android.app.AlarmManager;
import android.app.PendingIntent;
import android.content.Context;
import android.content.Intent;
import android.os.Bundle;

import com.tenqube.visual_third.entity.VisualNotification;
import com.tenqube.visual_third.repository.VisualRepository;
import com.tenqube.visual_third.service.AlarmService;
import com.tenqube.visual_third.util.Utils;

import java.util.ArrayList;
import java.util.Calendar;

import static tenqube.parser.core.ParserService.mIsDebug;
import static tenqube.parser.util.LogUtil.LOGI;

public class VisualAlarmManager {

    public static final String TAG = VisualAlarmManager.class.getSimpleName();
    private static final int ALARM_SET = 0;
    private static final int ALARM_REPEAT = 1;


    private Context context;
    private static VisualAlarmManager mInstance = null;
    private AlarmManager alarmManager;
    private VisualRepository repository;

    public static VisualAlarmManager getInstance(Context ctx) {
        synchronized (VisualAlarmManager.class) {
            if (mInstance == null) {
                mInstance = new VisualAlarmManager(ctx.getApplicationContext());
            }
        }
        return mInstance;
    }

    private VisualAlarmManager(Context context) {
        this.context = context;
        alarmManager = (AlarmManager) context.getSystemService(Context.ALARM_SERVICE);
        repository = VisualRepository.getInstance(context);
    }

    /**
     * 호출 시점
     * 1. 처음 진입시
     * 2. 설정 변경시
     */
    public void setAlarms() {

        ArrayList<VisualNotification> notifications = repository.loadNotifications();
        for(VisualNotification notification : notifications) {
            cancelAlarm(notification);
            if(notification.isEnable()) {
                setAlarm(notification);
            }
        }
    }

    private void setAlarm(VisualNotification notification) {
        PendingIntent pIntent = createPendingIntent(notification);
        long alarmTime = calculateAlarmTime(notification);
        long currentTime = System.currentTimeMillis();

        alarmManager.set(AlarmManager.RTC_WAKEUP, currentTime + alarmTime, pIntent);
    }

    private void cancelAlarm(VisualNotification notification) {
        PendingIntent pIntent = createPendingIntent(notification);
        alarmManager.cancel(pIntent);
    }

    private PendingIntent createPendingIntent(VisualNotification notification) {
        Intent intent = new Intent(context, AlarmService.class);

        Bundle bundle = new Bundle();
        bundle.putSerializable("data", notification);
        intent.putExtra("bundle", bundle);
        return PendingIntent.getService(context, notification.getId(), intent, PendingIntent.FLAG_UPDATE_CURRENT);
    }

    private long calculateAlarmTime(VisualNotification notification) {

        Calendar calendar = Calendar.getInstance();
        long currentTime = calendar.getTimeInMillis();
        int currentDay = calendar.get(Calendar.DATE);

        int currentHour = calendar.get(Calendar.HOUR_OF_DAY);

        calendar.set(Calendar.MINUTE, 0);
        calendar.set(Calendar.SECOND, 0);

        int day = notification.getDay();
        int dayOfWeek = notification.getDayOfWeek();
        int hour = notification.getHour();

        switch (notification.getName()) {
            case "monthly":
                if(day == currentDay) { // 1일로같음
                    if(currentHour >= hour) { // 알람설정 시간을 지나침
                        calendar.add(Calendar.MONTH, 1);
                    }
                } else {
                    calendar.add(Calendar.MONTH, 1);
                }

                calendar.set(Calendar.DATE, day);
                calendar.set(Calendar.HOUR_OF_DAY, hour);
                break;

            case "weekly_mon":
            case "weekly_fri":
                calendar.set(Calendar.HOUR_OF_DAY, hour);
                calendar.set(Calendar.DAY_OF_WEEK, dayOfWeek);

                if(currentTime >= calendar.getTimeInMillis()) {
                    calendar.add(Calendar.WEEK_OF_YEAR, 1);
                }
                break;

            case "daily":
                calendar.set(Calendar.HOUR_OF_DAY, hour);

                if(currentTime >= calendar.getTimeInMillis()) {
                    calendar.add(Calendar.DATE, 1);
                }
                break;
        }

        LOGI(TAG, "notification.getName()" + notification.getName(), mIsDebug);
        LOGI(TAG, "Alarm Date: " + Utils.getStringDateAsYYYYMMddHHmmss(calendar), mIsDebug);
        return calendar.getTimeInMillis();


    }

}
